Macro orzir_macros::caster

source ·
caster!() { /* proc-macro */ }
Create a caster for casting from one trait object to another.

Example

Below is an example of getting the Caster for casting from ModuleOp to IsIsolatedFromAbove.

caster!(ModuleOp => IsIsolatedFromAbove)