Macro orzir_macros::register_caster

source ·
register_caster!() { /* proc-macro */ }
Register a trait object caster in the context.

This is used if the interface/trait is not defined in the same crate as the operation/type.

Example

Below is an example of registering the caster from ModuleOp to IsIsolatedFromAbove.

register_caster!(ctx, ModuleOp => IsIsolatedFromAbove)