caster!() { /* proc-macro */ }
Create a caster for casting from one trait object to another.
Below is an example of getting the Caster for casting from ModuleOp to IsIsolatedFromAbove.
Caster
ModuleOp
IsIsolatedFromAbove
caster!(ModuleOp => IsIsolatedFromAbove)